curl-users
Re: cURL 7.2.2.0 Changes Display
Date: Thu, 22 Sep 2011 22:37:09 +0200 (CEST)
On Sat, 17 Sep 2011, Christopher Stone wrote:
> I just today updated curl to 7.2.2.0 via MacPorts and when I ran my
> downloader script I noticed a change in the Terminal output. I've been
> looking through the change log and the man page but don't find a means to
> revert back to the old, more compact display.
Like this?
diff --git a/lib/progress.c b/lib/progress.c
index 8966854..1514e1e 100644
--- a/lib/progress.c
+++ b/lib/progress.c
@@ -201,7 +201,8 @@ void Curl_pgrsStartNow(struct SessionHandle *data)
{
data->progress.speeder_c = 0; /* reset the progress meter display */
data->progress.start = Curl_tvnow();
- data->progress.flags &= PGRS_HIDE; /* clear all bits except HIDE */
+ /* clear all bits except HIDE and HEADERS_OUT */
+ data->progress.flags &= PGRS_HIDE|PGRS_HEADERS_OUT;
}
-- / daniel.haxx.se ------------------------------------------------------------------- List admin: http://cool.haxx.se/list/listinfo/curl-users FAQ: http://curl.haxx.se/docs/faq.html Etiquette: http://curl.haxx.se/mail/etiquette.htmlReceived on 2011-09-22